@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Victoria;
 
-$Map::Tube::London::Line::Victoria::VERSION   = '1.22';
+$Map::Tube::London::Line::Victoria::VERSION   = '1.23';
 $Map::Tube::London::Line::Victoria::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Victoria - London Tube Map: Victoria Line.
 
 =head1 VERSION
 
-Version 1.22
+Version 1.23
 
 =head1 DESCRIPTION
 
@@ -43,45 +43,43 @@ London Tube Map: Victoria Line.
 
 =over 2
 
-=item * The station "Finsbury Park" is also part of
-          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
+=item * The station "Blackhorse Road" is also part of
+          L<Overground Line|Map::Tube::London::Line::Overground>
 
 =item * The station "Euston" is also part of
-          L<Northern Line|Map::Tube::London::Line::Northern>.
+          L<Northern Line|Map::Tube::London::Line::Northern>
+        | L<Overground Line|Map::Tube::London::Line::Overground>
+
+=item * The station "Finsbury Park" is also part of
+          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "Green Park" is also part of
+          L<Jubilee Line|Map::Tube::London::Line::Jubilee>
+        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
+
+=item * The station "Highbury & Islington" is also part of
+          L<Overground Line|Map::Tube::London::Line::Overground>
 
 =item * The station "King's Cross St. Pancras" is also part of
           L<Circle Line|Map::Tube::London::Line::Circle>
         | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
         | L<Metropolitan Line|Map::Tube::London::Line::Metropolitan>
         | L<Northern Line|Map::Tube::London::Line::Northern>
-        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "Finsbury Park" is also part of
-          L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "Blackhorse Road" is also part of
-          L<London Overground Line|Map::Tube::London::Line::Overground>.
-
-=item * The station "Warren Street" is also part of
-          L<Northern Line|Map::Tube::London::Line::Northern>.
+        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>
 
 =item * The station "Oxford Circus" is also part of
           L<Bakerloo Line|Map::Tube::London::Line::Bakerloo>
-        | L<Central Line|Map::Tube::London::Line::Central>.
-
-=item * The station "Green Park" is also part of
-          L<Jubilee Line|Map::Tube::London::Line::Jubilee>
-        | L<Piccadilly Line|Map::Tube::London::Line::Piccadilly>.
-
-=item * The station "Victoria" is also part of
-          L<District Line|Map::Tube::London::Line::District>
-        | L<Circle Line|Map::Tube::London::Line::Circle>.
+        | L<Central Line|Map::Tube::London::Line::Central>
 
 =item * The station "Stockwell" is also part of
-          L<Northern Line|Map::Tube::London::Line::Northern>.
+          L<Northern Line|Map::Tube::London::Line::Northern>
 
-=item * The station "Highbury & Islington" is also part of
-          L<London Overground Line|Map::Tube::London::Line::Overground>.
+=item * The station "Victoria" is also part of
+          L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<District Line|Map::Tube::London::Line::District>
+
+=item * The station "Warren Street" is also part of
+          L<Northern Line|Map::Tube::London::Line::Northern>
 
 =back
 
